/**
* Copyright (C) 2005 BULL S.A.
*
* This file is part of Dolphin
*
* Dolphin : An open source J2EE Deployment Tool JSR-88 compliant
* Contact: ishmael-dev@objectweb.org
*
* Dolphin is free software; you can redistribute it and/or
* modify it under the terms of the GNU Lesser General Public
* License as published by the Free Software Foundation; either
* version 2.1 of the License, or any later version.
*
* Dolphin is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
* Lesser General Public License for more details.
*
* You should have received a copy of the GNU Lesser General Public
* License along with Dolphin; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
* USA
*/
package org.objectweb.dolphin.dialogs;

import org.eclipse.jface.dialogs.Dialog;
import org.eclipse.swt.SWT;
import org.eclipse.swt.events.SelectionAdapter;
import org.eclipse.swt.events.SelectionEvent;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Button;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.DirectoryDialog;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.swt.widgets.Text;
import org.objectweb.dolphin.resources.DolphinResourcesManagment;

/**
 * Class who implements the UI of the Change Workspace Dialog
 * @author Bourgeon J?r?me, Macherel Bruno
 */
public class DialogWorkspace extends Dialog{
	private String text ="";

	/**
     * Creates a dialog instance. Note that the window will have no visual
     * representation (no widgets) until it is told to open. By default,
     * <code>open</code> blocks for dialogs.
     *
     * @param parentShell
     *            the parent shell, or <code>null</code> to create a top-level
     *            shell
	 */
	public DialogWorkspace(Shell parentShell) {
		super(parentShell);
	}

	/**
	 * Method who open a Directory Dialog
	 * @return the path of the directory
	 */
	private String queryFile() {
		DirectoryDialog dialog= new DirectoryDialog(new Shell(), SWT.OPEN);
		dialog.setText("Switch Workspace"); //$NON-NLS-1$
		String path= dialog.open();
		if (path != null && path.length() > 0)
			return path;
		return null;
	}

	/**
	 * @see org.eclipse.jface.dialogs.Dialog#createDialogArea(org.eclipse.swt.widgets.Composite)
	 */
	public Control createDialogArea(Composite parent){
		Composite composite = (Composite) super.createDialogArea(parent);
		GridLayout grid = new GridLayout(2,true);
		composite.setLayout(grid);
		GridData gd = new GridData(GridData.FILL_HORIZONTAL);

		Label old = new Label(composite, SWT.BOLD);
		old.setText("Old workspace : "+DolphinResourcesManagment.getWorkspace());
		gd.horizontalSpan=2;
		old.setLayoutData(gd);
		gd = new GridData(GridData.FILL_HORIZONTAL);

		//The Label
		Label label = new Label(composite, SWT.BOLD);
		label.setText("Select the new workspace :");
		gd.horizontalSpan=2;
		label.setLayoutData(gd);

		//The File Browser
		gd = new GridData(GridData.FILL_HORIZONTAL);
		final Text textField = new Text(composite,SWT.BORDER);
		textField.setBounds(10,10,300,20);
		textField.setLayoutData(gd);
		gd = new GridData(GridData.FILL_HORIZONTAL);
		Button button = new Button(composite,SWT.PUSH);
		button.setText("Browse");
		button.addSelectionListener(new SelectionAdapter() {
			public void widgetSelected(SelectionEvent e) {
				text = queryFile();
				textField.setText(text);
			}
		});
		button.setLayoutData(gd);


		return composite;
	}

	/**
	 * Set the new workspace in the application
	 * @see org.eclipse.jface.dialogs.Dialog#okPressed()
	 */
	protected void okPressed() {
		DolphinResourcesManagment.setWorkspace(text);
		super.okPressed();
	}




}
