/**
* Copyright (C) 2005 BULL S.A.
*
* This file is part of Dolphin
*
* Dolphin : An open source J2EE Deployment Tool JSR-88 compliant
* Contact: ishmael-dev@objectweb.org
*
* Dolphin is free software; you can redistribute it and/or
* modify it under the terms of the GNU Lesser General Public
* License as published by the Free Software Foundation; either
* version 2.1 of the License, or any later version.
*
* Dolphin is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
* Lesser General Public License for more details.
*
* You should have received a copy of the GNU Lesser General Public
* License along with Dolphin; if not, write to the Free Software
* Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
* USA
*/
package org.objectweb.dolphin.preferences;

import org.eclipse.jface.preference.*;
import org.eclipse.ui.IWorkbenchPreferencePage;
import org.eclipse.ui.IWorkbench;
import org.objectweb.dolphin.DolphinPlugin;
import org.objectweb.dolphin.resources.DolphinResourcesManagment;

/**
 * This class represents a preference page that
 * is contributed to the Preferences dialog. By
 * subclassing <samp>FieldEditorPreferencePage</samp>, we
 * can use the field support built into JFace that allows
 * us to create a page that is small and knows how to
 * save, restore and apply itself.
 * <p>
 * This page is used to modify preferences only. They
 * are stored in the preference store that belongs to
 * the main plug-in class. That way, preferences can
 * be accessed directly via the preference store.
 *
 * @author Bourgeon J?r?me, Macherel Bruno
 *
 */
public class DriversPreferencePage
	extends FieldEditorPreferencePage
	implements IWorkbenchPreferencePage {

	private StringFieldEditor name;
	private StringFieldEditor pattern;
	private DirectoryFieldEditor directory;


	/**
	 * Create a new DolphinPreferencePage
	 */
	public DriversPreferencePage() {
		super(GRID);

		setPreferenceStore(DolphinPlugin.getDefault().getPreferenceStore());
		setDescription("Manage JSR-88 drivers");
	}

	/**
	 * Creates the field editors. Field editors are abstractions of
	 * the common GUI blocks needed to manipulate various types
	 * of preferences. Each field editor knows how to save and
	 * restore itself.
	 *
	 * @see org.eclipse.jface.preference.FieldEditorPreferencePage#createFieldEditors()
	 */
	public void createFieldEditors() {
		name = new StringFieldEditor(PreferenceConstants.P_DRIVER_NAME, "Driver name:", getFieldEditorParent());
		pattern = new StringFieldEditor(PreferenceConstants.P_DRIVER_PATTERN, "uri:", getFieldEditorParent());
		directory = new DirectoryFieldEditor(PreferenceConstants.P_DRIVER_NAME,"&Select a driver:", getFieldEditorParent());
		directory.setChangeButtonText("Browse");
		addField(name);
		addField(pattern);
		addField(directory);
	}

	/**
	 * @see org.eclipse.ui.IWorkbenchPreferencePage#init(org.eclipse.ui.IWorkbench)
	 */
	public void init(IWorkbench workbench) {
	}

	/**
	 * Save the workspace
	 * @see org.eclipse.jface.preference.IPreferencePage#performOk()
	 */
	public boolean performOk() {
		performApply();
		return super.performOk();
	}

	/**
	 * Save the workspace
	 * @see org.eclipse.jface.preference.PreferencePage#performApply()
	 */
	protected void performApply() {
		DolphinResourcesManagment.addDriver(name.getStringValue(), pattern.getStringValue(), directory.getStringValue());
	}

	/**
	 * @see org.eclipse.jface.preference.IPreferencePage#performCancel()
	 */
	public boolean performCancel() {
		return super.performCancel();
	}


}